# Cegon Set1

Cegon Set1 is a dependency package created by **Cegon Technologies**.

It installs all required Python libraries for:

- Machine Learning
- Deep Learning
- NLP
- Data Science
- Computer Vision

## Installation

```bash
pip install cegon-set1